"""
English linguistic markers for epistemic detection.
"""

MARKERS = {
    "uncertainty": [
        r"\bi'?m not sure\b",
        r"\bi don'?t know\b",
        r"\bi think\b",
        r"\bmaybe\b",
        r"\bperhaps\b",
        r"\bmight be\b",
        r"\bcould be\b",
        r"\bpossibly\b",
        r"\buncertain\b",
        r"\bnot certain\b",
        r"\bi believe\b",
        r"\bit seems\b",
        r"\bprobably\b",
        r"\blikely\b",
        r"\bunlikely\b",
        r"\bunclear\b",
        r"\bif i recall\b",
        r"\bif i remember\b",
        r"\bnot entirely sure\b",
        r"\bhard to say\b",
        r"\bdifficult to determine\b",
        r"\bappears to\b",
    ],
    "overconfidence": [
        r"\bdefinitely\b",
        r"\bcertainly\b",
        r"\bcertainty\b",
        r"\bcertain\b",
        r"\babsolutely\b",
        r"\balways\b",
        r"\bnever\b",
        r"\bundoubtedly\b",
        r"\bclearly\b",
        r"\bobviously\b",
        r"\bwithout a doubt\b",
        r"\bwithout doubt\b",
        r"\bguaranteed\b",
        r"100\s?%",
        r"\bmust be\b",
        r"\bno question\b",
        r"\bexactly\b",
        r"\bprecisely\b",
    ],
    "fabrication": [
        r"as of my (last |knowledge )?cutoff",
        r"i don'?t have access to",
        r"i cannot browse",
        r"my training data",
        r"as an ai",
        r"as a language model",
        r"i cannot provide",
        r"i don'?t have real-?time",
    ],
    "unanswerable": [
        r"what will .+ (be worth|be|happen|cost) in \d{4}",
        r"worth in \d{4}",
        r"who will win",
        r"stock (price|market) .*(tomorrow|next|future|\d{4})",
        r"\bpredict\b",
        r"lottery",
        r"(next|this) (week|month|year).*(will|going to)",
        r"in \d{4}.*(will|be worth|cost)",
    ],
}
